<?php
/*
Plugin Name: Subscribe Sidebar
Plugin URI: http://www.blubrry.com/subscribe-sidebar/
Description: Blubrry Subscribe sidebar widget with links to subscribe to feeds and twitter stream
Author: Angelo Mandato - Blubrry
Version: 1.1.1
Author URI: http://www.blubrry.com/
*/

define('SUBSCRIBE_SIDEBAR_VERSION', 1.1.1);


function subscribe_sidebar($show_header=true)
{
	// Default blog information
	$site_url = get_bloginfo('url');
	$blog_name = get_bloginfo('name');
	$rss2_url = get_bloginfo('rss2_url');
	$atom_url = get_bloginfo('atom_url');
	$podcast_url = get_feed_link('podcast'); // Created by Podpress
	
	$plugin_url = get_bloginfo('url').'/wp-content/plugins/'.basename(dirname(__FILE__)).'/';
	
	$options = get_option('subscribe_sidebar');
	if( !isset($options['title']) || $options['title'] == '' )
		$options['title'] = __('Subscribe');
	if( isset($options['custom_style']) )
		unset($options['custom_style']);
	
	if( !$options ) // Default subscribe options
	{
		$options['rss2'] = true;
		$options['google'] = true;
		$options['yahoo'] = true;
	}

	$icons = array('feed'=>'feed.png', 'twitter'=>'twitter.png', 'google'=>'google.png', 'yahoo'=>'yahoo.png', 'itunes'=>'itunes.png', 'zune'=>'zune.png' );
	
	if( $show_header )
		echo "<h2>{$options['title']}</h2>\n";
	echo "\t<ul id=\"subscribe_sidebar_list\">\n";
	
	while( list($key,$value) = each($options) )
	{
		if( $value && $key != 'note_author' && $key != 'title' )
		{
			echo "\t\t<li>";
			
			switch( $key )
			{
				case 'twitter': {
					echo '<a href="http://twitter.com/'. $value .'" title="Twitter"><img src="'.$plugin_url.$icons[$key].'" alt="Twitter" /></a>';
					echo '<a href="http://twitter.com/'. $value .'" title="Twitter">Twitter</a>';
				}; break;
				
				case 'yahoo': {
					echo '<a href="http://add.my.yahoo.com/rss?url='. urlencode($rss2_url) .'" title="Add to My Yahoo"><img src="'.$plugin_url.$icons[$key].'" alt="Add to My Yahoo" /></a>';
					echo '<a href="http://add.my.yahoo.com/rss?url='. urlencode($rss2_url) .'" title="Add to My Yahoo">My Yahoo</a>';
				}; break;
				
				case 'google': {
					echo '<a href="http://fusion.google.com/add?feedurl='. urlencode($rss2_url) .'" title="Add to Google Reader/Homepage"><img src="'.$plugin_url.$icons[$key].'" alt="Add to Google Reader/Homepage" /></a>';
					echo '<a href="http://fusion.google.com/add?feedurl='. urlencode($rss2_url) .'" title="Add to Google Reader/Homepage">Add to Google</a>';
				}; break;
				
				case 'itunes': {
					$link = str_replace('http://', 'itpc://', $rss2_url);
					if( strlen($value) > 5 )
						$link = htmlspecialchars($value);
						
					echo '<a href="'. $link .'" title="Add to iTunes"><img src="'.$plugin_url.$icons[$key].'" alt="Add to iTunes" /></a>';
					echo '<a href="'. $link .'" title="Add to iTunes">Add to iTunes</a>';
				}; break;
				
				case 'zune': {
					echo '<a href="zune://subscribe/?'.str_replace('+', '_', urlencode($blog_name) ). '='. $rss2_url .'" title="Add to Zune"><img src="'.$plugin_url.$icons[$key].'" alt="Add to Zune" /></a>';
					echo '<a href="zune://subscribe/?'.str_replace('+', '_', urlencode($blog_name) ). '='. $rss2_url .'" title="Add to Zune">Add to Zune</a>';
				}; break;
				
				case 'podcast': {
					echo '<a href="'. $podcast_url .'" title="Podcast RSS Feed"><img src="'.$plugin_url.$icons['feed'].'" alt="Podcast RSS Feed" /></a>';
					echo '<a href="'. $podcast_url .'" title="Podcast RSS Feed">Podcast Feed</a>';
				}; break;
				
				case 'atom': {
					echo '<a href="'. $atom_url .'" title="Atom Feed"><img src="'.$plugin_url.$icons['feed'].'" alt="Atom Feed" /></a>';
					echo '<a href="'. $atom_url .'" title="Atom Feed">Atom Feed</a>';
				}; break;
				
				case 'rss2': {
					echo '<a href="'. $rss2_url .'" title="RSS Feed"><img src="'.$plugin_url.$icons['feed'].'" alt="RSS Feed" /></a>';
					echo '<a href="'. $rss2_url .'" title="RSS Feed">RSS Feed</a>';
				}; break;
				
				case 'note_author': {
					// Do nothing for this option here
				}; break;
				
				default: {
					$link = $rss2_url;
					if( strlen($value) > 5 )
						$link = $value;
					echo '<a href="'. $link .'" title="'. $key .'"><img src="'.$plugin_url.$icons[$key].'" alt="'. $key .'" /></a>';
					echo '<a href="'. $link .'" title="'. $key .'">'. $key .'</a>';
				}; break;
			}
			echo "</li>\n";
		}
	}
	
	echo "\t</ul>\n";		
	if( isset($options['note_author']) && $options['note_author'] )
	{
		echo '<div style="margin-top: 8px;"><span style="font-size: 10px; border-top: 1px dotted;">Subscribe plugin by <a href="http://www.rawvoice.com/greenhouse/subscribe-sidebar/" target="_blank" title="Subscribe plugin by RawVoice">RawVoice</a></span></div>';
	}
}


function subscribe_sidebar_header($args)
{
	$options = get_option('subscribe_sidebar');
	if( @$options['custom_style'] != true )
		echo "\n<!-- Subscribe Sidebar widget -->\n<link rel=\"stylesheet\" href=\"".get_bloginfo('url')."/wp-content/plugins/".basename(dirname(__FILE__))."/subscribe_sidebar.css\" type=\"text/css\" media=\"screen\" />\n";
}

function widget_subscribe_sidebar_init()
{
	if( !function_exists('register_sidebar_widget') || !function_exists('register_widget_control') )
		return;
	
	function widget_subscribe_sidebar($args)
	{
		extract($args);
		$options = get_option('subscribe_sidebar');
		if( !isset($options['title']) || $options['title'] == '' )
			$options['title'] = __('Subscribe');
		
		echo "<!-- Start Subscribe Sidebar widget -->\n";
		echo $before_widget . $before_title . $options['title'] . $after_title;
		echo '<div id="subscribe_sidebar">';
		subscribe_sidebar(false);
		echo '</div>';
		echo $after_widget;
		echo "\t<!-- End Subscribe Sidebar widget -->\n";
	}
	
	register_sidebar_widget('Subscribe', 'widget_subscribe_sidebar');
}

function subscribe_sidebar_admin_page()
{
		if ($_POST['subscribe_sidebar'] ) {
			if( $_POST['subscribe_sidebar']['twitter'] )
				$_POST['subscribe_sidebar']['twitter'] = $_POST['TwitterName'];
				
			if( $_POST['subscribe_sidebar']['itunes'] && $_POST['iTunesURL'] )
				$_POST['subscribe_sidebar']['itunes'] = $_POST['iTunesURL'];
			
			update_option('subscribe_sidebar', $_POST['subscribe_sidebar']);
		}
	
		$options = get_option('subscribe_sidebar');
		if( !$options )
		{
			$options['rss2'] = true;
			$options['google'] = true;
			$options['yahoo'] = true;
		}
	
		?>
<style type="text/css">
	fieldset{margin:20px 0; 
	border:1px solid #cecece;
	padding:15px;
	}
</style>
<div class="wrap">
	<h2>Blubrry Subscribe Sidebar Options</h2>
	
	<?php
	if( $_GET['status'] )
	{
		echo "<div style=\"width:100%; color: #770000; font-weight: normal;\">Status: ";
		echo $_GET['status'];
		echo "</div>\n";
	}
?>
	<form method="post">
	
	<div class="submit"><input type="submit" name="info_update" value="<?php _e('Update Options') ?> &raquo;" /></div>
	
	<div>
		<fieldset class="options">
			<legend><?php echo __('Subscribe Links:'); ?></legend>
			<p>Select the links to display in the Subscribe Sidebar.</p>
			
			<ul>
			<li>
				<label for="subscribe_sidebar[rss2]">
				<input name="subscribe_sidebar[rss2]" type="checkbox" id="subscribe_sidebar_rss2" value="1" <?php checked('1', $options['rss2']); ?> />
				<?php _e('RSS 2.0 Feed'); ?></label>
			</li>
			<li>
				<label for="subscribe_sidebar[atom]">
				<input name="subscribe_sidebar[atom]" type="checkbox" id="subscribe_sidebar_atom" value="1" <?php checked('1', $options['atom']); ?> />
				<?php _e('Atom Feed'); ?></label>
			</li>
<?php if ( subscribe_sidebar_podcast_check() ) { ?>
			<li>
				<label for="subscribe_sidebar[podcast]">
				<input name="subscribe_sidebar[podcast]" type="checkbox" id="subscribe_sidebar_podcast" value="1" <?php checked('1', $options['podcast']); ?> />
				<?php _e('Podcast RSS 2.0 Feed'); ?></label>
			</li>
<?php } ?>
			<li>
				<label for="subscribe_sidebar[google]">
				<input name="subscribe_sidebar[google]" type="checkbox" id="subscribe_sidebar_google" value="1" <?php checked('1', $options['google']); ?> />
				<?php _e('Google Reader/Homepage'); ?></label>
			</li>
			<li>
				<label for="subscribe_sidebar[yahoo]">
				<input name="subscribe_sidebar[yahoo]" type="checkbox" id="subscribe_sidebar_yahoo" value="1" <?php checked('1', $options['yahoo']); ?> />
				<?php _e('My Yahoo'); ?></label>
			</li>
			<li>
				<label for="subscribe_sidebar[itunes]">
				<input name="subscribe_sidebar[itunes]" type="checkbox" id="subscribe_sidebar_itunes" value="1" <?php echo ( $options['itunes'] ? 'checked':''); ?> />
				<?php _e('iTunes (for podcast subscription)'); ?></label>
				<p>
					<label for="iTunesURL">Your iTunes URL:</label>
					<input type="text" name="iTunesURL" id="itunesurl" value="<?php if( strlen($options['itunes']) > 4 ) echo($options['itunes']); ?>" /> (leave blank if unknown)
				</p>
				<p>
					Don't have your podcast listed on iTunes? Install and run <a href="http://www.apple.com/itunes/download/" target="_blank" title="iTunes">iTunes</a>, then <a href="https://phobos.apple.com/WebObjects/MZFinance.woa/wa/publishPodcast" target="_blank" title="Publish a Podcast on iTunes">Publish a Podcast</a> on iTunes.
				</p>
			</li>
			<li>
				<label for="subscribe_sidebar[zune]">
				<input name="subscribe_sidebar[zune]" type="checkbox" id="subscribe_sidebar_zune" value="1" <?php checked('1', $options['zune']); ?> />
				<?php _e('Zune (for podcast subscription)'); ?></label>
			</li>
			<li>
				<label for="subscribe_sidebar[twitter]">
				<input name="subscribe_sidebar[twitter]" type="checkbox" id="subscribe_sidebar_twitter" value="1" <?php echo ( $options['twitter'] ? 'checked':''); ?> />
				<?php _e('Twitter'); ?></label>
				<p>
					<label for="twitterlogin">Your Twitter Name:</label>
					<input type="text" name="TwitterName" id="twittername" value="<?php if($options['twitter']) echo($options['twitter']); ?>" />
				</p>
				<p>
					Don't have a <a href="http://twitter.com/" target="_blank" title="Twitter">Twitter</a> account? You should, <a href="http://twitter.com/" target="_blank" title="Twitter">Twitter</a> is a great way to communicate with your blog readers and podcast audience.
				</p>
			</li>
			</ul>
		</fieldset>
		
		<fieldset class="options">
			<legend><?php echo __('Display Options:'); ?></legend>
			<ul>
			<li>
				<label for="subscribe_sidebar[custom_style]">
				<input name="subscribe_sidebar[custom_style]" type="checkbox" id="subscribe_sidebar_custom_style" value="1" <?php checked('1', $options['custom_style']); ?> />
				<?php _e('Override Icon Styling (disables default styling, relies on theme sidebar styling)'); ?></label>
			</li>
			<li>
				<label for="subscribe_sidebar[note_author]">
				<input name="subscribe_sidebar[note_author]" type="checkbox" id="subscribe_sidebar_note_author" value="1" <?php checked('1', $options['note_author']); ?> />
				<?php _e('Note Author under Subscribe list (displays &quot;Subscribe plugin by <a href="http://www.rawvoice.com/greenhouse/subscribe-sidebar/" target="_blank" title="Subscribe plugin by RawVoice">RawVoice</a>&quot; at bottom of list)'); ?></label>
			</li>
				<li>
				<p>
					<label for="subscribe_sidebar_title">Heading Title:</label>
					<input type="text" name="subscribe_sidebar[title]" id="subscribe_sidebar_title" value="<?php echo htmlspecialchars($options['title']); ?>" /> (Leave blank for default: Subscribe)
				</p>
			</li>
			</ul>
		</fieldset>

		</div>
	<div class="submit"><input type="submit" name="info_update" value="<?php _e('Update Options') ?> &raquo;" /></div>
	</form>
</div>

<div class="wrap">

	<p style="font-size: 85%; text-align: center; padding-bottom: 25px;">
		<a href="http://www.blubrry.com/subscribe_sidebar/" title="Blubrry Subscribe Sidebar" target="_blank">Blubrry Subscribe Sidebar</a> <?php echo SUBSCRIBE_SIDEBAR_VERSION; ?>	&#8212; <a href="http://twitter.com/blubrry" target="_blank" title="Follow Blubrry on Twitter">Follow Blubrry on Twitter</a>
	</p>

</div>
<?php
}

function subscribe_sidebar_podcast_check()
{
	if( defined('POWERPRESS_VERSION') )
		return true;
	$current_plugins = get_option('active_plugins');
	if (in_array('podpress/podpress.php', $current_plugins))
		return true;
	if (in_array('podcasting/podcasting.php', $current_plugins))
		return true;
	return false;
}

function subscribe_sidebar_admin()
{
	add_options_page('Subscribe Sidebar', 'Subscribe Sidebar', 9, 'subscribe_sidebar.php', 'subscribe_sidebar_admin_page');
}
add_action('admin_menu','subscribe_sidebar_admin',1);
	
add_action('wp_head', 'subscribe_sidebar_header');
add_action('plugins_loaded', 'widget_subscribe_sidebar_init');

?>